@@ -4,7 +4,7 @@
  * See the file COPYING in the toplevel directory of the source directory.
  */
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <klocale.h>			/* i18n */
 #include <kmessagebox.h>
 #include <kconfig.h>
@@ -80,6 +80,7 @@ DebuggerMainWnd::DebuggerMainWnd(const char* name) :
     m_bpTable->setDebugger(m_debugger);
     m_memoryWindow->setDebugger(m_debugger);
 
+    setStandardToolBarMenuEnabled(true);
     initKAction();
     initToolbar(); // kind of obsolete?
 
@@ -87,8 +88,6 @@ DebuggerMainWnd::DebuggerMainWnd(const char* name) :
     connect(m_watches, SIGNAL(deleteWatch()), m_debugger, SLOT(slotDeleteWatch()));
     connect(m_watches, SIGNAL(textDropped(const QString&)), SLOT(slotAddWatch(const QString&)));
 
-    KAction* windowMenu = actionCollection()->action("window");
-    m_filesWindow->setWindowMenu(static_cast<KActionMenu*>(windowMenu)->popupMenu());
     connect(&m_filesWindow->m_findDlg, SIGNAL(closed()), SLOT(updateUI()));
     connect(m_filesWindow, SIGNAL(newFileLoaded()),
 	    SLOT(slotNewFileLoaded()));
@@ -110,8 +109,8 @@ DebuggerMainWnd::DebuggerMainWnd(const char* name) :
     // disassembling
     connect(m_filesWindow, SIGNAL(disassemble(const QString&, int)),
 	    m_debugger, SLOT(slotDisassemble(const QString&, int)));
-    connect(m_debugger, SIGNAL(disassembled(const QString&,int,const QList<DisassembledCode>&)),
-	    m_filesWindow, SLOT(slotDisassembled(const QString&,int,const QList<DisassembledCode>&)));
+    connect(m_debugger, SIGNAL(disassembled(const QString&,int,const std::list<DisassembledCode>&)),
+	    m_filesWindow, SLOT(slotDisassembled(const QString&,int,const std::list<DisassembledCode>&)));
     connect(m_filesWindow, SIGNAL(moveProgramCounter(const QString&,int,const DbgAddr&)),
 	    m_debugger, SLOT(setProgramCounter(const QString&,int,const DbgAddr&)));
     // program stopped
@@ -120,10 +119,6 @@ DebuggerMainWnd::DebuggerMainWnd(const char* name) :
     // tab width
     connect(this, SIGNAL(setTabWidth(int)), m_filesWindow, SIGNAL(setTabWidth(int)));
 
-    // file/line updates
-    connect(m_filesWindow, SIGNAL(fileChanged()), SLOT(slotFileChanged()));
-    connect(m_filesWindow, SIGNAL(lineChanged()), SLOT(slotLineChanged()));
-
     // connect breakpoint table
     connect(m_bpTable, SIGNAL(activateFileLine(const QString&,int,const DbgAddr&)),
 	    m_filesWindow, SLOT(activate(const QString&,int,const DbgAddr&)));
@@ -131,19 +126,19 @@ DebuggerMainWnd::DebuggerMainWnd(const char* name) :
     connect(m_debugger, SIGNAL(breakpointsChanged()), m_bpTable, SLOT(updateBreakList()));
     connect(m_debugger, SIGNAL(breakpointsChanged()), m_bpTable, SLOT(updateUI()));
 
-    connect(m_debugger, SIGNAL(registersChanged(QList<RegisterInfo>&)),
-	    m_registers, SLOT(updateRegisters(QList<RegisterInfo>&)));
+    connect(m_debugger, SIGNAL(registersChanged(const std::list<RegisterInfo>&)),
+	    m_registers, SLOT(updateRegisters(const std::list<RegisterInfo>&)));
 
-    connect(m_debugger, SIGNAL(memoryDumpChanged(const QString&, QList<MemoryDump>&)),
-	    m_memoryWindow, SLOT(slotNewMemoryDump(const QString&, QList<MemoryDump>&)));
+    connect(m_debugger, SIGNAL(memoryDumpChanged(const QString&, const std::list<MemoryDump>&)),
+	    m_memoryWindow, SLOT(slotNewMemoryDump(const QString&, const std::list<MemoryDump>&)));
     connect(m_debugger, SIGNAL(saveProgramSpecific(KConfigBase*)),
 	    m_memoryWindow, SLOT(saveProgramSpecific(KConfigBase*)));
     connect(m_debugger, SIGNAL(restoreProgramSpecific(KConfigBase*)),
 	    m_memoryWindow, SLOT(restoreProgramSpecific(KConfigBase*)));
 
     // thread window
-    connect(m_debugger, SIGNAL(threadsChanged(QList<ThreadInfo>&)),
-	    m_threads, SLOT(updateThreads(QList<ThreadInfo>&)));
+    connect(m_debugger, SIGNAL(threadsChanged(const std::list<ThreadInfo>&)),
+	    m_threads, SLOT(updateThreads(const std::list<ThreadInfo>&)));
     connect(m_threads, SIGNAL(setThread(int)),
 	    m_debugger, SLOT(setThread(int)));
 
@@ -158,7 +153,6 @@ DebuggerMainWnd::DebuggerMainWnd(const char* name) :
 
     updateUI();
     m_bpTable->updateUI();
-    slotFileChanged();
 }
 
 DebuggerMainWnd::~DebuggerMainWnd()
@@ -185,6 +179,7 @@ void DebuggerMainWnd::initKAction()
     KAction* open = KStdAction::open(this, SLOT(slotFileOpen()), 
                       actionCollection());
     open->setText(i18n("&Open Source..."));
+    KStdAction::close(m_filesWindow, SLOT(slotClose()), actionCollection());
     (void)new KAction(i18n("&Reload Source"), "reload", 0, m_filesWindow, 
                       SLOT(slotFileReload()), actionCollection(), 
                       "file_reload");
@@ -196,7 +191,7 @@ void DebuggerMainWnd::initKAction()
 		      actionCollection(), "file_executable_recent");
     (void)new KAction(i18n("&Core dump..."), 0, this, SLOT(slotFileCore()),
                       actionCollection(), "file_core_dump");
-    KStdAction::quit(this, SLOT(slotFileQuit()), actionCollection());
+    KStdAction::quit(kapp, SLOT(closeAllWindows()), actionCollection());
 
     // settings menu
     (void)new KAction(i18n("This &Program..."), 0, this,
@@ -206,13 +201,15 @@ void DebuggerMainWnd::initKAction()
                       SLOT(slotFileGlobalSettings()), actionCollection(),
                       "settings_global");
     KStdAction::keyBindings(this, SLOT(slotConfigureKeys()), actionCollection());
-    KStdAction::showToolbar(this, SLOT(slotViewToolbar()), actionCollection());
     KStdAction::showStatusbar(this, SLOT(slotViewStatusbar()), actionCollection());
 
     // view menu
     (void)new KToggleAction(i18n("&Find"), "find", CTRL+Key_F, m_filesWindow,
 			    SLOT(slotViewFind()), actionCollection(),
 			    "view_find");
+    (void)KStdAction::findNext(m_filesWindow, SLOT(slotFindForward()), actionCollection(), "view_findnext");
+    (void)KStdAction::findPrev(m_filesWindow, SLOT(slotFindBackward()), actionCollection(), "view_findprev");
+
     i18n("Source &code");
     struct { QString text; QWidget* w; QString id; } dw[] = {
 	{ i18n("Stac&k"), m_btWindow, "view_stack"},
@@ -297,8 +294,6 @@ void DebuggerMainWnd::initKAction()
 		      SLOT(slotEditValue()), actionCollection(),
 		      "edit_value");
 
-    (void)new KActionMenu(i18n("&Window"), actionCollection(), "window");
-
     // all actions force an UI update
     QValueList<KAction*> actions = actionCollection()->actions();
     QValueList<KAction*>::Iterator it = actions.begin();
@@ -312,9 +307,6 @@ void DebuggerMainWnd::initKAction()
 void DebuggerMainWnd::initToolbar()
 {
     KToolBar* toolbar = toolBar("mainToolBar");
-    toolbar->setBarPos(KToolBar::Top);
-    //moveToolBar(toolbar);
-    
     toolbar->insertAnimatedWidget(ID_STATUS_BUSY,
 	actionCollection()->action("exec_break"), SLOT(activate()),
 	"pulse", -1);
@@ -324,7 +316,6 @@ void DebuggerMainWnd::initToolbar()
     KStatusBar* statusbar = statusBar();
     statusbar->insertItem(m_statusActive, ID_STATUS_ACTIVE);
     m_lastActiveStatusText = m_statusActive;
-    statusbar->insertItem(i18n("Line 00000"), ID_STATUS_LINENO);
     statusbar->insertItem("", ID_STATUS_MSG);	/* message pane */
 
     // reserve some translations
@@ -332,21 +323,12 @@ void DebuggerMainWnd::initToolbar()
     i18n("Core dump");
 }
 
-/*
- * We must override KTMainWindow's handling of close events since we have
- * only one toplevel window, which lives on the stack (which KTMainWindow
- * can't live with :-( )
- */
-void DebuggerMainWnd::closeEvent(QCloseEvent* e)
+bool DebuggerMainWnd::queryClose()
 {
-    clearWFlags(WDestructiveClose);
-
     if (m_debugger != 0) {
 	m_debugger->shutdown();
     }
-
-    e->accept();
-    kapp->quit();
+    return true;
 }
 
 
@@ -459,6 +441,8 @@ void DebuggerMainWnd::updateUI()
     actionCollection()->action("file_executable")->setEnabled(m_debugger->isIdle());
     actionCollection()->action("settings_program")->setEnabled(m_debugger->haveExecutable());
     actionCollection()->action("file_core_dump")->setEnabled(m_debugger->canStart());
+    actionCollection()->action("file_close")->setEnabled(m_filesWindow->hasWindows());
+    actionCollection()->action("file_reload")->setEnabled(m_filesWindow->hasWindows());
     actionCollection()->action("exec_step_into")->setEnabled(m_debugger->canSingleStep());
     actionCollection()->action("exec_step_into_by_insn")->setEnabled(m_debugger->canSingleStep());
     actionCollection()->action("exec_step_over")->setEnabled(m_debugger->canSingleStep());
@@ -496,7 +480,6 @@ void DebuggerMainWnd::updateUI()
 	statusBar()->changeItem(newStatus, ID_STATUS_ACTIVE);
 	m_lastActiveStatusText = newStatus;
     }
-    // line number is updated in slotLineChanged
 }
 
 void DebuggerMainWnd::dockUpdateHelper(QString action, QWidget* w)
@@ -528,40 +511,6 @@ void DebuggerMainWnd::slotAddWatch(const QString& text)
     }
 }
 
-void DebuggerMainWnd::slotFileChanged()
-{
-    // set caption
-    QString caption;
-
-    if (m_debugger->haveExecutable()) {
-	// basename part of executable
-	QString executable = m_debugger->executable();
-	const char* execBase = executable.data();
-	int lastSlash = executable.findRev('/');
-	if (lastSlash >= 0)
-	    execBase += lastSlash + 1;
-	caption += execBase;
-    }
-    QString file;
-    int line;
-    bool anyWindows = m_filesWindow->activeLine(file, line);
-    updateLineStatus(anyWindows ? line : -1);
-    if (anyWindows) {
-	caption += " (";
-	caption += file;
-	caption += ")";
-    }
-    setCaption(caption);
-}
-
-void DebuggerMainWnd::slotLineChanged()
-{
-    QString file;
-    int line;
-    bool anyWindows = m_filesWindow->activeLine(file, line);
-    updateLineStatus(anyWindows ? line : -1);
-}
-
 void DebuggerMainWnd::slotNewFileLoaded()
 {
     // updates program counter in the new file
@@ -569,17 +518,6 @@ void DebuggerMainWnd::slotNewFileLoaded()
 	m_filesWindow->updateLineItems(m_debugger);
 }
 
-void DebuggerMainWnd::updateLineStatus(int lineNo)
-{
-    if (lineNo < 0) {
-	statusBar()->changeItem("", ID_STATUS_LINENO);
-    } else {
-	QString strLine;
-	strLine.sprintf(i18n("Line %d"), lineNo + 1);
-	statusBar()->changeItem(strLine, ID_STATUS_LINENO);
-    }
-}
-
 KDockWidget* DebuggerMainWnd::dockParent(QWidget* w)
 {
     while ((w = w->parentWidget()) != 0) {
@@ -639,7 +577,7 @@ TTYWindow* DebuggerMainWnd::ttyWindow()
     return m_ttyWindow;
 }
 
-bool DebuggerMainWnd::debugProgram(const QString& exe, QCString lang)
+bool DebuggerMainWnd::debugProgram(const QString& exe, const QString& lang)
 {
     // check the file name
     QFileInfo fi(exe);
@@ -662,6 +600,10 @@ bool DebuggerMainWnd::debugProgram(const QString& exe, QCString lang)
 	// keep the directory
 	m_lastDirectory = fi.dirPath(true);
 	m_filesWindow->setExtraDirectory(m_lastDirectory);
+
+	// set caption to basename part of executable
+	QString caption = fi.fileName();
+	setCaption(caption);
     }
     else
     {
@@ -850,14 +792,6 @@ void DebuggerMainWnd::slotFileOpen()
     }
 }
 
-void DebuggerMainWnd::slotFileQuit()
-{
-    if (m_debugger != 0) {
-	m_debugger->shutdown();
-    }
-    kapp->quit();
-}
-
 void DebuggerMainWnd::slotFileExe()
 {
     if (m_debugger->isIdle())
@@ -891,20 +825,13 @@ void DebuggerMainWnd::slotFileProgSettings()
     }
 }
 
-void DebuggerMainWnd::slotViewToolbar()
-{
-    if (toolBar()->isVisible())
-	toolBar()->hide();
-    else
-	toolBar()->show();
-}
-
 void DebuggerMainWnd::slotViewStatusbar()
 {
     if (statusBar()->isVisible())
 	statusBar()->hide();
     else
 	statusBar()->show();
+    setSettingsDirty();
 }
 
 void DebuggerMainWnd::slotExecUntil()
