@@ -10,32 +10,31 @@
 #include "qlistview.h"
 #include <qlineedit.h>
 #include <qpixmap.h>
-#include <qptrlist.h>
-#include <qstrlist.h>
+#include <list>
 
 class ProgramTypeTable;
 class TypeInfo;
 struct ExprValue;
 class ExprWnd;
+class QStringList;
 
-/* a variable's value is the tree of sub-variables */
-
+/*! \brief a variable's value is the tree of sub-variables */
 class VarTree : public QListViewItem
 {
 public:
     enum VarKind { VKsimple, VKpointer, VKstruct, VKarray,
-	VKdummy				/* used to update only children */
+	VKdummy				//!< used to update only children
     };
     VarKind m_varKind;
     enum NameKind { NKplain, NKstatic, NKtype,
-	NKanonymous,			/* an anonymous struct or union */
-	NKaddress			/* a dereferenced pointer */
+	NKanonymous,			//!< an anonymous struct or union
+	NKaddress			//!< a dereferenced pointer
     };
     NameKind m_nameKind;
-    TypeInfo* m_type;			/* type of struct */
-    int m_exprIndex;			/* used in struct value update */
-    bool m_exprIndexUseGuard;		/* ditto; if guard expr should be used */
-    QString m_partialValue;		/* while struct value update is in progress */
+    TypeInfo* m_type;			//!< the type of struct if it could be derived
+    int m_exprIndex;			//!< used in struct value update
+    bool m_exprIndexUseGuard;		//!< ditto; if guard expr should be used
+    QString m_partialValue;		//!< while struct value update is in progress
 
     VarTree(VarTree* parent, QListViewItem* after, ExprValue* v);
     VarTree(ExprWnd* parent, QListViewItem* after, const QString& name);
@@ -121,8 +120,8 @@ public:
     ExprWnd(QWidget* parent, const QString& colHeader, const char* name);
     ~ExprWnd();
 
-    /** fills the list with the expressions at the topmost level */
-    void exprList(QStrList& exprs);
+    /** returns the list with the expressions at the topmost level */
+    QStringList exprList() const;
     /** appends a copy of expr to the end of the tree at the topmost level;
      * returns a pointer to the inserted top-level item */
     VarTree* insertExpr(ExprValue* expr, ProgramTypeTable& typeTable);
@@ -134,7 +133,7 @@ public:
     /** updates only the value of the node */
     void updateStructValue(VarTree* display);
     /** get a top-level expression by name */
-    VarTree* topLevelExprByName(const char* name);
+    VarTree* topLevelExprByName(const QString& name) const;
     /** return a member of the struct that pointer \a v refers to */
     static VarTree* ptrMemberByName(VarTree* v, const QString& name);
     /** return a member of the struct \a v */
@@ -163,15 +162,15 @@ protected:
     static QString formatWCharPointer(QString value);
     QPixmap m_pixPointer;
 
-    QList<VarTree> m_updatePtrs;	/* dereferenced pointers that need update */
-    QList<VarTree> m_updateType;	/* structs whose type must be determined */
-    QList<VarTree> m_updateStruct;	/* structs whose nested value needs update */
+    std::list<VarTree*> m_updatePtrs;	//!< dereferenced pointers that need update
+    std::list<VarTree*> m_updateType;	//!< structs whose type must be determined
+    std::list<VarTree*> m_updateStruct;	//!< structs whose nested value needs update
 
     ValueEdit* m_edit;
 
     /** remove items that are in the subTree from the list */
     void unhookSubtree(VarTree* subTree);
-    static void unhookSubtree(QList<VarTree>& list, VarTree* subTree);
+    static void unhookSubtree(std::list<VarTree*>& list, VarTree* subTree);
 
 signals:
     void removingItem(VarTree*);
