@@ -4,11 +4,11 @@
  * See the file COPYING in the toplevel directory of the source directory.
  */
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <klocale.h>			/* i18n */
 #include <kmessagebox.h>
 #include <kglobal.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kcmdlineargs.h> 
 #include <kaboutdata.h>
 #include <kpopupmenu.h>
@@ -37,7 +37,7 @@ int main(int argc, char** argv)
 			 VERSION,
 			 I18N_NOOP("A Debugger"),
 			 KAboutData::License_GPL, 
-			 "(c) 1998-2008 Johannes Sixt",
+			 "(c) 1998-2009 Johannes Sixt",
 			 0,		/* any text */
 			 "http://www.kdbg.org/",
 			 "j6t@kdbg.org");
@@ -55,6 +55,7 @@ int main(int argc, char** argv)
 	{ "r <device>", I18N_NOOP("remote debugging via <device>"), 0 },
 	{ "l <language>", I18N_NOOP("specify language: C, XSLT"), ""},
 	{ "x", I18N_NOOP("use language XSLT (deprecated)"), 0 },
+	{ "a <args>", I18N_NOOP("specify arguments of debugged executable"), 0},
 	{ "p <pid>", I18N_NOOP("specify PID of process to debug"), 0},
 	{ "+[program]", I18N_NOOP("path of executable to debug"), 0 },
 	{ "+[core]", I18N_NOOP("a core file to use"), 0},
@@ -66,7 +67,7 @@ int main(int argc, char** argv)
 
     KGlobal::dirs()->addResourceType("types", "share/apps/kdbg/types");
 
-    DebuggerMainWnd debugger("kdbg_main");
+    DebuggerMainWnd* debugger = new DebuggerMainWnd("kdbg_main");
 
     /* type libraries */
     TypeTable::initTypeLibraries();
@@ -75,25 +76,24 @@ int main(int argc, char** argv)
     bool restored = false;
     if (app.isRestored()) {
 	if (KMainWindow::canBeRestored(1)) {
-	    debugger.restore(1);
+	    debugger->restore(1);
 	    restored = true;
 	}
     }
 
-    app.setMainWidget(&debugger);
+    app.setMainWidget(debugger);
 
-    debugger.show();
+    debugger->show();
 
     // handle options
 
     KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
-    QCString t = args->getOption("t");
-    const char* transcript = t.data();
+    QString transcript = args->getOption("t");
     QString remote = args->getOption("r");
     if (!remote.isEmpty())
-	debugger.setRemoteDevice(remote);
+	debugger->setRemoteDevice(remote);
 
-    QCString lang = args->getOption("l");
+    QString lang = args->getOption("l");
 
     // deprecated option; overrides -l
     if (args->isSet("x")){
@@ -102,30 +102,35 @@ int main(int argc, char** argv)
     }
 
     // check environment variable for transcript file name
-    if (transcript == 0) {
+    if (transcript.isEmpty()) {
 	transcript = getenv("KDBG_TRANSCRIPT");
     }
-    debugger.setTranscript(transcript);
+    debugger->setTranscript(transcript);
 
     QString pid = args->getOption("p");
+    QString programArgs = args->getOption("a");
 
     if (!restored && args->count() > 0) {
 	// attach to process?
 	if (!pid.isEmpty()) {
 	    TRACE("pid: " + pid);
-	    debugger.setAttachPid(pid);
+	    debugger->setAttachPid(pid);
 	}
 	// check for core file; use it only if we're not attaching to a process
 	else if (args->count() > 1 && pid.isEmpty()) {
-	    debugger.setCoreFile(args->arg(1));
+	    debugger->setCoreFile(args->arg(1));
 	}
-	if (!debugger.debugProgram(args->arg(0), lang)) {
+	if (!debugger->debugProgram(args->arg(0), lang)) {
 	    // failed
 	    TRACE("cannot start debugger");
-	    KMessageBox::error(&debugger, i18n("Cannot start debugger."));
+	    KMessageBox::error(debugger, i18n("Cannot start debugger."));
 
-	    debugger.setCoreFile(QString());
-	    debugger.setAttachPid(QString());
+	    debugger->setCoreFile(QString());
+	    debugger->setAttachPid(QString());
+	} else {
+	    if (!programArgs.isEmpty()) {
+		debugger->overrideProgramArguments(programArgs);
+	    }
 	}
     }
 
