@@ -11,13 +11,11 @@
 #include <qlistview.h>
 #include <qcombobox.h>
 #include <qlayout.h>
-#include <qdict.h>
-#include <qptrlist.h>
 #include <qmap.h>
+#include "dbgdriver.h"
 
 class KDebugger;
 class KConfigBase;
-struct MemoryDump;
 
 class MemoryWindow : public QWidget
 {
@@ -38,7 +36,7 @@ protected:
     QVBoxLayout m_layout;
 
     unsigned m_format;
-    QDict<unsigned> m_formatCache;
+    QMap<QString,unsigned> m_formatCache;
 
     QPopupMenu m_popup;
 
@@ -49,7 +47,7 @@ protected:
 public slots:
     void slotNewExpression(const QString&);
     void slotTypeChange(int id);
-    void slotNewMemoryDump(const QString&, QList<MemoryDump>&);
+    void slotNewMemoryDump(const QString&, const std::list<MemoryDump>&);
     void saveProgramSpecific(KConfigBase* config);
     void restoreProgramSpecific(KConfigBase* config);
 };
