@@ -10,9 +10,10 @@
 #include <qpainter.h>
 #include <qbrush.h>
 #include <qfile.h>
+#include <qfileinfo.h>
 #include <qkeycode.h>
 #include <qpopupmenu.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kiconloader.h>
 #include <kglobalsettings.h>
 #include <kmainwindow.h>
@@ -23,12 +24,13 @@
 #include "mydebug.h"
 
 
-SourceWindow::SourceWindow(const char* fileName, QWidget* parent, const char* name) :
+SourceWindow::SourceWindow(const QString& fileName, QWidget* parent, const char* name) :
 	QTextEdit(parent, name),
 	m_fileName(fileName),
 	m_curRow(-1),
 	m_widthItems(16),
-	m_widthPlus(12)
+	m_widthPlus(12),
+	m_widthLineNo(30)
 {
     // load pixmaps
     m_pcinner = UserIcon("pcinner");
@@ -40,7 +42,7 @@ SourceWindow::SourceWindow(const char* fileName, QWidget* parent, const char* na
     m_brkorph = UserIcon("brkorph");
     setFont(KGlobalSettings::fixedFont());
     setReadOnly(true);
-    setMargins(m_widthItems+m_widthPlus, 0, 0 ,0);
+    setMargins(m_widthItems+m_widthPlus+m_widthLineNo, 0, 0 ,0);
     setAutoFormatting(AutoNone);
     setTextFormat(PlainText);
     setWordWrap(NoWrap);
@@ -83,6 +85,10 @@ bool SourceWindow::loadFile()
     }
     m_lineItems.resize(n, 0);
 
+    // set a font for line numbers
+    m_lineNoFont = currentFont();
+    m_lineNoFont.setPixelSize(11);
+
     return true;
 }
 
@@ -148,6 +154,7 @@ void SourceWindow::drawFrame(QPainter* p)
     clip &= QRegion(inside);
     p->setClipRegion(clip);
 
+    p->setFont(m_lineNoFont);
     p->setPen(colorGroup().text());
     p->eraseRect(inside);
 
@@ -203,9 +210,9 @@ void SourceWindow::drawFrame(QPainter* p)
 	    if (y < 0) y = 0;
 	    p->drawPixmap(0,y,m_pcup);
 	}
+	p->translate(m_widthItems, 0);
 	if (!isRowDisassCode(row) && m_sourceCode[rowToLine(row)].canDisass) {
 	    int w = m_widthPlus;
-	    p->translate(m_widthItems, 0);
 	    int x = w/2;
 	    int y = h/2;
 	    p->drawLine(x-2, y, x+2, y);
@@ -213,6 +220,11 @@ void SourceWindow::drawFrame(QPainter* p)
 		p->drawLine(x, y-2, x, y+2);
 	    }
 	}
+	p->translate(m_widthPlus, 0);
+	if (!isRowDisassCode(row)) {
+	    p->drawText(0, 0, m_widthLineNo, h, AlignRight|AlignVCenter,
+			QString().setNum(rowToLine(row)+1));
+	}
 	p->restore();
     }
     p->restore();
@@ -226,9 +238,9 @@ void SourceWindow::updateLineItems(const KDebugger* dbg)
 	    // check if this breakpoint still exists
 	    int line = rowToLine(i);
 	    TRACE(QString().sprintf("checking for bp at %d", line));
-	    int j;
-	    for (j = dbg->numBreakpoints()-1; j >= 0; j--) {
-		const Breakpoint* bp = dbg->breakpoint(j);
+	    KDebugger::BrkptROIterator bp = dbg->breakpointsBegin();
+	    for (; bp != dbg->breakpointsEnd(); ++bp)
+	    {
 		if (bp->lineNo == line &&
 		    fileNameMatches(bp->fileName) &&
 		    lineToRow(line, bp->address) == i)
@@ -237,7 +249,7 @@ void SourceWindow::updateLineItems(const KDebugger* dbg)
 		    break;
 		}
 	    }
-	    if (j < 0) {
+	    if (bp == dbg->breakpointsEnd()) {
 		/* doesn't exist anymore, remove it */
 		m_lineItems[i] &= ~liBPany;
 		update();
@@ -246,8 +258,8 @@ void SourceWindow::updateLineItems(const KDebugger* dbg)
     }
 
     // add new breakpoints
-    for (int j = dbg->numBreakpoints()-1; j >= 0; j--) {
-	const Breakpoint* bp = dbg->breakpoint(j);
+    for (KDebugger::BrkptROIterator bp = dbg->breakpointsBegin(); bp != dbg->breakpointsEnd(); ++bp)
+    {
 	if (fileNameMatches(bp->fileName)) {
 	    TRACE(QString().sprintf("updating %s:%d", bp->fileName.data(), bp->lineNo));
 	    int i = bp->lineNo;
@@ -442,23 +454,10 @@ void SourceWindow::paletteChange(const QPalette& oldPal)
  */
 bool SourceWindow::fileNameMatches(const QString& other)
 {
-    const QString& me = fileName();
-
-    // check for null file names first
-    if (me.isNull() || other.isNull()) {
-	return me.isNull() && other.isNull();
-    }
-
-    /*
-     * Get file names.  Note: Either there is a slash, then skip it, or
-     * there is no slash, then -1 + 1 = 0!
-     */
-    int sme = me.findRev('/') + 1;
-    int sother = other.findRev('/') + 1;
-    return strcmp(me.data() + sme, other.data() + sother) == 0;
+    return QFileInfo(other).fileName() == QFileInfo(m_fileName).fileName();
 }
 
-void SourceWindow::disassembled(int lineNo, const QList<DisassembledCode>& disass)
+void SourceWindow::disassembled(int lineNo, const std::list<DisassembledCode>& disass)
 {
     TRACE("disassembled line " + QString().setNum(lineNo));
     if (lineNo < 0 || lineNo >= int(m_sourceCode.size()))
@@ -467,12 +466,12 @@ void SourceWindow::disassembled(int lineNo, const QList<DisassembledCode>& disas
     SourceLine& sl = m_sourceCode[lineNo];
 
     // copy disassembled code and its addresses
-    sl.disass.resize(disass.count());
-    sl.disassAddr.resize(disass.count());
-    sl.canDisass = disass.count() > 0;
-    for (uint i = 0; i < disass.count(); i++) {
-	const DisassembledCode* c =
-	    const_cast<QList<DisassembledCode>&>(disass).at(i);
+    sl.disass.resize(disass.size());
+    sl.disassAddr.resize(disass.size());
+    sl.canDisass = !disass.empty();
+    int i = 0;
+    for (std::list<DisassembledCode>::const_iterator c = disass.begin(); c != disass.end(); ++c, ++i)
+    {
 	QString code = c->code;
 	while (code.endsWith("\n"))
 	    code.truncate(code.length()-1);
@@ -725,8 +724,6 @@ void SourceWindow::cursorChanged(int row)
 	clearParagraphBackground(m_curRow);
     m_curRow = row;
     setParagraphBackgroundColor(row, colorGroup().background());
-
-    emit lineChanged();
 }
 
 /*
