@@ -21,7 +21,7 @@ class SourceWindow : public QTextEdit
 {
     Q_OBJECT
 public:
-    SourceWindow(const char* fileName, QWidget* parent, const char* name);
+    SourceWindow(const QString& fileName, QWidget* parent, const char* name);
     ~SourceWindow();
     
     bool loadFile();
@@ -48,7 +48,7 @@ public:
     bool isRowDisassCode(int row);
 
     /** lineNo is zero-based */
-    void disassembled(int lineNo, const QList<DisassembledCode>& disass);
+    void disassembled(int lineNo, const std::list<DisassembledCode>& disass);
 
     void activeLine(int& lineNo, DbgAddr& address);
 
@@ -74,7 +74,6 @@ signals:
     void disassemble(const QString&, int);
     void expanded(int lineNo);		/* source lineNo has been expanded */
     void collapsed(int lineNo);		/* source lineNo has been collapsed */
-    void lineChanged();
 public slots:
     void setTabWidth(int numChars);
     void cursorChanged(int row);
@@ -106,9 +105,11 @@ protected:
     QPixmap m_brktmp;			/* temporary breakpoint marker */
     QPixmap m_brkcond;			/* conditional breakpoint marker */
     QPixmap m_brkorph;			/* orphaned breakpoint marker */
+    QFont m_lineNoFont;			//!< The font used to draw line numbers
     int m_curRow;			//!< The highlighted row
     int m_widthItems;			//!< The width of the item column
     int m_widthPlus;			//!< The width of the expander column
+    int m_widthLineNo;			//!< The width of the line number columns
 };
 
 class HighlightCpp : public QSyntaxHighlighter
