@@ -96,6 +96,7 @@ static XsldbgCmdInfo cmds[] = {
     {DCcondition, "print 'condition %d %s'\n", XsldbgCmdInfo::argNumString},
     {DCsetpc, "print 'set variable $pc=%s'\n", XsldbgCmdInfo::argString},
     {DCignore, "print 'ignore %d %d'\n", XsldbgCmdInfo::argNum2},
+    {DCprintWChar, "print 'ignore %s'\n", XsldbgCmdInfo::argString},
     {DCsetvariable, "set %s %s\n", XsldbgCmdInfo::argString2},
 };
 
@@ -685,9 +686,11 @@ isErrorExpr(const char *output)
     };
     
     for (wordIndex = 0; wordIndex < ERROR_WORD_COUNT; wordIndex++){
+      // ignore any warnings relating to local variables not being available
       if (strncmp(output, 
 		  errorWords[wordIndex], 
-		  errorWordLength[wordIndex]) == 0){
+		  errorWordLength[wordIndex]) == 0 && 
+		    (wordIndex == 0 && strstr(output, "try stepping past the xsl:param") == 0) )   {
 	result = true;
         TRACE(QString("Error/Warning/Information from xsldbg ") + output);
 	break;
@@ -1090,21 +1093,21 @@ parseFrame(const char *&s, int &frameNo, QString & func,
 
 void
 XsldbgDriver::parseBackTrace(const char *output,
-                             QList < StackFrame > &stack)
+                             std::list < StackFrame > &stack)
 {
     QString func, file;
     int lineNo, frameNo;
     DbgAddr address;
 
     while (::parseFrame(output, frameNo, func, file, lineNo, address)) {
-        StackFrame *frm = new StackFrame;
+        stack.push_back(StackFrame());
+        StackFrame* frm = &stack.back();
 
         frm->frameNo = frameNo;
         frm->fileName = file;
         frm->lineNo = lineNo;
         frm->address = address;
         frm->var = new ExprValue(func, VarTree::NKplain);
-        stack.append(frm);
     }
 }
 
@@ -1121,28 +1124,21 @@ XsldbgDriver::parseFrameChange(const char *output, int &frameNo,
 
 bool
 XsldbgDriver::parseBreakList(const char *output,
-                             QList < Breakpoint > &brks)
+                             std::list < Breakpoint > &brks)
 {
    TRACE("parseBreakList");
     /* skip the first blank line */
    const char *p;
    
     // split up a line
-    QString location, file, lineNo;
-    QString address;
-    QString templateName;	 
-    int hits = 0;
-    int enabled = 0;
-    uint ignoreCount = 0;
-    QString condition;
+    Breakpoint bp;
     char *dummy;
     p =  strchr(output, '\n');/* skip the first blank line*/
 
     while ((p != 0) && (*p != '\0')) {
 	if (*p == '\n')
 	    p++;
-        templateName = QString();
-        Breakpoint::Type bpType = Breakpoint::breakpoint;
+        QString templateName;
         //qDebug("Looking at :%s", p);
         if (strncmp(p, " Breakpoint", 11) != 0)
             break;
@@ -1152,7 +1148,7 @@ XsldbgDriver::parseBreakList(const char *output,
 
         //TRACE(p);
         // get Num
-        long bpNum = strtol(p, &dummy, 10);     /* don't care about overflows */
+        bp.id = strtol(p, &dummy, 10);     /* don't care about overflows */
 
         p = dummy;
         if ((p == 0) || (p[1] == '\0'))
@@ -1162,12 +1158,12 @@ XsldbgDriver::parseBreakList(const char *output,
         //TRACE(p);    
         // Get breakpoint state ie enabled/disabled
         if (strncmp(p, "enabled", 7) == 0) {
-            enabled = true;
+            bp.enabled = true;
             p = p + 7;
         } else {
             if (strncmp(p, "disabled", 8) == 0) {
                 p = p + 8;
-                enabled = false;
+                bp.enabled = false;
             } else{
 	      TRACE("Parse error in breakpoint list");
 	      TRACE(p);
@@ -1218,6 +1214,7 @@ XsldbgDriver::parseBreakList(const char *output,
 	if (*p == '\"')
 	    p++;
         /* grab file name */
+        QString file;
         while ((*p != '\"') && !isspace(*p)) {
             file.append(*p);
             p++;
@@ -1233,36 +1230,17 @@ XsldbgDriver::parseBreakList(const char *output,
             p++;
         }
         //TRACE(p);    
+        QString lineNo;
         while (isdigit(*p)) {
             lineNo.append(*p);
             p++;
         }
 
-
-
-        Breakpoint *bp = new Breakpoint;
-        if (bp != 0) {
-            // take 1 of line number
-            lineNo.setNum(lineNo.toInt() -1);
-            bp->id = bpNum;
-            bp->type = bpType;
-            bp->temporary = false;
-            bp->enabled = enabled;
-            location.append("in ").append(templateName).append(" at ");
-	    location.append(file).append(":").append(lineNo);
-            bp->location = location;
-            bp->fileName = file;
-            bp->lineNo = lineNo.toInt();
-            bp->address = address;
-            bp->hitCount = hits;
-            bp->ignoreCount = ignoreCount;
-            bp->condition = condition;
-            brks.append(bp);
-            location = "";
-            lineNo = "";
-            file = "";
-        } else
-            TRACE("Outof memory, breakpoint not created");
+        // bp.lineNo is zero-based
+        bp.lineNo = lineNo.toInt() - 1;
+        bp.location = QString("in %1 at %2:%3").arg(templateName, file, lineNo);
+        bp.fileName = file;
+        brks.push_back(bp);
 
         if (p != 0) {
             p = strchr(p, '\n');
@@ -1273,11 +1251,10 @@ XsldbgDriver::parseBreakList(const char *output,
     return true;
 }
 
-bool
-XsldbgDriver::parseThreadList(const char */*output*/,
-                              QList < ThreadInfo > &/*threads*/)
+std::list<ThreadInfo>
+XsldbgDriver::parseThreadList(const char */*output*/)
 {
-    return true;
+    return std::list<ThreadInfo>();
 }
 
 bool
@@ -1309,7 +1286,7 @@ XsldbgDriver::parseBreakpoint(const char *output, int &id,
 }
 
 void
-XsldbgDriver::parseLocals(const char *output, QList < ExprValue > &newVars)
+XsldbgDriver::parseLocals(const char *output, std::list < ExprValue* > &newVars)
 {
 
     /* keep going until error or xsldbg prompt is found */
@@ -1320,14 +1297,14 @@ XsldbgDriver::parseLocals(const char *output, QList < ExprValue > &newVars)
             break;
         }
         // do not add duplicates
-        for (ExprValue * o = newVars.first(); o != 0; o = newVars.next()) {
-            if (o->m_name == variable->m_name) {
+        for (std::list<ExprValue*>::iterator o = newVars.begin(); o != newVars.end(); ++o) {
+            if ((*o)->m_name == variable->m_name) {
                 delete variable;
 
                 goto skipDuplicate;
             }
         }
-        newVars.append(variable);
+        newVars.push_back(variable);
       skipDuplicate:;
     }
 }
@@ -1426,10 +1403,10 @@ XsldbgDriver::parseProgramStopped(const char *output, QString & message)
     return flags;
 }
 
-void
-XsldbgDriver::parseSharedLibs(const char */*output*/, QStrList & /*shlibs*/)
+QStringList
+XsldbgDriver::parseSharedLibs(const char */*output*/)
 {
-    /* empty */
+    return QStringList();
 }
 
 bool
@@ -1438,11 +1415,10 @@ XsldbgDriver::parseFindType(const char */*output*/, QString & /*type*/)
     return true;
 }
 
-void
-XsldbgDriver::parseRegisters(const char */*output*/,
-                             QList < RegisterInfo > &/*regs*/)
+std::list<RegisterInfo> 
+XsldbgDriver::parseRegisters(const char */*output*/)
 {
-
+    return std::list<RegisterInfo>();
 }
 
 bool
@@ -1452,16 +1428,15 @@ XsldbgDriver::parseInfoLine(const char */*output*/, QString & /*addrFrom*/,
     return false;
 }
 
-void
-XsldbgDriver::parseDisassemble(const char */*output*/,
-                               QList < DisassembledCode > &/*code*/)
+std::list<DisassembledCode>
+XsldbgDriver::parseDisassemble(const char */*output*/)
 {
-    /* empty */
+    return std::list<DisassembledCode>();
 }
 
 QString
 XsldbgDriver::parseMemoryDump(const char */*output*/,
-                              QList < MemoryDump > &/*memdump*/)
+                              std::list < MemoryDump > &/*memdump*/)
 {
     return i18n("No memory dump available");
 }
